% GetAtn(temp, transmittance, a, type)
% Estimates k-sigma for each of four species. 
% tempK is passed to allow for temperature dependence; presently not used.
% atten is attenuation; basea is a (see Boparai et al 2008)
% zval is normal z, number of standard deviations from mean. 

function atnvals = GetAtn(tempK, tr, basea, zval)

% Primarily called by Step2.m
% copyleft info at end of file

% Must be defined elsewhere
global SpeciesN 
global occ ocv och pc lac

% Assume central value if zval not given
if nargin<4
    zval = zeros(1, SpeciesN);
end

% start with zero attenuation
atnvals = zeros(1, SpeciesN);

% Values for charrable OC - leave zero for now

% Values for volatile OC - leave zero for now

% Values for heavy OC - leave zero for now

% Values for pyrolytic carbon
pcavg = 45;
pcstd = 4.2;
atnvals(pc) = pcavg + zval(pc) * pcstd;

% Values for LAC (see Boparai et al 2008)
ba = 8.2796 + 6.6749 * zval(lac);
r =  5.8655 - 0.4755 * zval(lac);

atnvals(lac) = basea(lac) * (1 + ba * exp(-r * (1-tr)));

% Fail-safe: ATN-LAC must be at least 25% lower than ATN-PC (otherwise the
% matrix becomes singular). This is a bit of a kludge, but it affects only 
% the very last LAC to leave the filter. 
atnvals(lac) = min(atnvals(lac), atnvals(pc) *0.75);
   
return

% Author: Tami Bond, University of Illinois, yark@uiuc.edu
% Version 2.1    Last modified: 29 Nov 2007
% This program is distributed under the Creative Commons by-sa license 3.0
%   (http://creativecommons.org/licenses/by-sa/3.0/).
