% Get a temperature program by providing the program length. 
% Arguments: proglen (program length)
% Optional 2nd argument: tprog_mat (prevents file reading every time)
function [tp, fracid]=GetTempProgram(proglen, tprog_mat)

% Temp program matrix: 1st col is program number; remaining columns are
%   length of temperature steps
if length(proglen)>1
    proglen = length(proglen);
end
if nargin<2
    tprog_mat = csvread('TempPrograms.csv', 1, 0);
end

progidx = 2:size(tprog_mat, 2);

% total program length
progsum = sum(tprog_mat(1:2:size(tprog_mat, 1), progidx), 2);

% find the one that matches length
progtag = (find(progsum==proglen, 1)-1)*2+1;

if ~isempty(progtag)
   timesteps = tprog_mat(progtag, progidx);
   fracid = tprog_mat(progtag+1, progidx);
   
   % remove zero steps
   progidx = find(timesteps>0);
   timesteps = timesteps(progidx);
   fracid = fracid(progidx);

% No program found
else
   timesteps = [];
   fracid = [];
end
    
tp=[];
tnext = 0;
for i=1:length(timesteps)
    tp = [tp; tnext+1 tnext+timesteps(i)];
    tnext = tnext + timesteps(i);
end

return
