% Step_Assumption(osin, stepno, atype) sets up the matrix equation to 
%   solve. All assumptions about the system are specified here. 
% Input arguments:
% osdat      structure containing crunched step info
% n          time step number to analyze

function [R, stepy] = Step_Assumption(osdat, n)
global SpeciesN occ ocv lac pc
global zerocarb

   % Basic response matrix
   stepy = [osdat.FID(n); osdat.cATN(n)];                 
   
   % Basic transfer function
   R = [ones(1, SpeciesN); osdat.ks(n,:)];

   % Add yield constraints to R and y matrix 
   if osdat.mode(n)==1 & ~osdat.atnloss(n)        % Inert: PC equal to charrable
     [R, stepy] = Assumption(R, stepy, 'pc=occ', 0, occ, 1, pc, 1);  % PC equal to charrable
     
   elseif osdat.mode(n)==2            % Oxidizer, or atn loss: no change in charrable OC
      [R, stepy] = Assumption(R, stepy, 'occ=0a', 0, occ, 1);  % no change in charrable OC
      
   else
      [R, stepy] = Assumption(R, stepy, 'occ=0b', 0, occ, 1);  % no change in charrable OC       
   end

   % OC assumptions
   if osdat.ocgone(n)             % No OC present
     [R, stepy] = Assumption(R, stepy, 'ocv=0', 0, ocv, 1);
     
   elseif ~osdat.atnloss(n) & osdat.FID(n)>zerocarb     % No ATN loss--> no LAC released
     [R, stepy] = Assumption(R, stepy, 'lac=0', 0, lac, 1);
     
   end
   
return

% --- Add assumption. oldR is the transfer matrix; oldy is the response matrix;
% labl is a tag for debugging; newsum is the sum of the components; 
% varargin is (component, coeff)
function [newR, newy] = Assumption(oldR, oldy, labl, newsum, varargin)
global SpeciesN                   % from main program

%disp(labl);

% Start with zero vector 
  dvec = zeros([1 SpeciesN]);
  % Loop through remaining input arguments
  for i=1:2:(nargin-4)
      idxno = varargin{i};
      dvec(idxno)=dvec(idxno)+varargin{i+1};
  end

  % add to matrix if any argument pairs were passed
  if nargin>4
     newR = [oldR; dvec];
     newy = [oldy; newsum];
  end

  return
