% Step_Underdet(mat) gives the range of solutions for an underdetermined
%   system. Returns [rangematrix, error]. mat must be in reduced row
%   echelon form. 

function [rangemat, rerr] = Step_Underdet(rechin)
% Errors returned: 0/nothing; 1/solution line doesn't intersect Quadrant 1; 
%   2/solution line intersects Q1 but is unconstrained; 10/unexpected
%   situation

% This case has not been treated yet; so far, it hasn't been needed
if rechin(1, 5)~=0
    rangemat = [];
    rerr = 10;
    
% Three evolving simultaneously: OCv, LAC, PC
else
    [rangemat, rerr] = Carbon3a(rechin);
end

return

% --- OCv+PC+LAC ----------------------------------------------
function [rangemat, rerr] = Carbon3a(rechin)

global ocv occ lac pc
global SpeciesN
global cpts isq1

% Find points where solution line intersects coordinate planes. 
y2=rechin(2,5);
b2=rechin(2,4);
y3=rechin(3,5);
b3=rechin(3,4);

% Matrix c contains the coordinates of these points (in rows).
cpts = [0 0 0 0;
    0 0 (y3-y2*b3/b2) y2/b2;...
    0 (y2-y3*b2/b3) 0 y3/b3;...
    0 y2 y3 0];

% Determine which points are on a face of Quadrant I. 
% Vector isq1 is 1 if there are two positive points (ie Q1).
isq1 = (sum(cpts>0,2)>=2)';

% Set up return matrix and error code
rangemat = [];
rerr = 0;

% --- Treat each case separately ------------------
% Fewer than two points on Q1 faces
nintersect = sum(isq1);
if nintersect==0
   rerr = 1;
    
elseif nintersect == 1
   rerr = 2;    
   
% Two points on Q1 faces-- provides a range of solutions
% that is physical
else
    idx = find(isq1==1);
    rangemat = cpts(idx, :); 
end

% Sort in order of LAC
if size(rangemat,1)>1
   [tmp, sidx] = sort(rangemat(:,lac));
   rangemat = rangemat(sidx, :);
end

% Transpose to columns. rangemat is returned
rangemat = rangemat';

return
